summaryrefslogtreecommitdiff
path: root/pango/pango-renderer.c
diff options
context:
space:
mode:
authorOwen Taylor <otaylor@redhat.com>2005-01-04 19:11:42 +0000
committerOwen Taylor <otaylor@src.gnome.org>2005-01-04 19:11:42 +0000
commit692994bc6e617b78d9f463a80c25998a416b730f (patch)
tree281151a3c505ff02fb7b5322b19992fb46f0ee18 /pango/pango-renderer.c
parent8a31da2ec82afd88219ec4221015373ccff390fd (diff)
downloadpango-692994bc6e617b78d9f463a80c25998a416b730f.tar.gz
Rename y1 parameters to y1_ to avoid conflicts with the math.h Bessel
Tue Jan 4 14:05:13 2005 Owen Taylor <otaylor@redhat.com> * pango/pango-renderer.c (pango_renderer_draw_trapezoid): Rename y1 parameters to y1_ to avoid conflicts with the math.h Bessel function. (#161969)
Diffstat (limited to 'pango/pango-renderer.c')
-rw-r--r--pango/pango-renderer.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/pango/pango-renderer.c b/pango/pango-renderer.c
index 04d5b761..6a4ba3c6 100644
--- a/pango/pango-renderer.c
+++ b/pango/pango-renderer.c
@@ -910,7 +910,7 @@ pango_renderer_default_draw_error_underline (PangoRenderer *renderer,
* pango_renderer_draw_trapezoid:
* @renderer: a #PangoRenderer
* @part: type of object this trapezoid is part of
* @y1: Y coordinate of top of trapezoid
* @x11: X coordinate of left end of top of trapezoid
* @x21: X coordinate of right end of top of trapezoid
* @y2: X coordinate of top of trapezoid
@@ -925,7 +925,7 @@ pango_renderer_default_draw_error_underline (PangoRenderer *renderer,
void
pango_renderer_draw_trapezoid (PangoRenderer *renderer,
PangoRenderPart part,
- double y1,
+ double y1_,
double x11,
double x21,
double y2,
@@ -936,7 +936,7 @@ pango_renderer_draw_trapezoid (PangoRenderer *renderer,
g_return_if_fail (renderer->active_count > 0);
PANGO_RENDERER_GET_CLASS (renderer)->draw_trapezoid (renderer, part,
- y1, x11, x21,
+ y1_, x11, x21,
y2, x12, x22);
}
@@ -910,7 +910,7 @@ pango_renderer_default_draw_error_underline (PangoRenderer *renderer,
* @renderer: a #PangoRenderer
* @part: type of object this trapezoid is part of
- * @y1: Y coordinate of top of trapezoid
+ * @y1_: Y coordinate of top of trapezoid
* @x11: X coordinate of left end of top of trapezoid
* @x21: X coordinate of right end of top of trapezoid